@@ -133,14 +133,14 @@ Profile::Profile(std::string path) {
 }
 
 // Generate JSON string of this object
-std::string Profile::Json() {
+std::string Profile::Json() const {
 
 	// Return formatted string
 	return JsonValue().toStyledString();
 }
 
-// Generate Json::JsonValue for this object
-Json::Value Profile::JsonValue() {
+// Generate Json::Value for this object
+Json::Value Profile::JsonValue() const {
 
 	// Create root json object
 	Json::Value root;
@@ -163,24 +163,12 @@ Json::Value Profile::JsonValue() {
 }
 
 // Load JSON string into this object
-void Profile::SetJson(std::string value) {
+void Profile::SetJson(const std::string value) {
 
 	// Parse JSON string into JSON objects
-	Json::Value root;
-	Json::CharReaderBuilder rbuilder;
-	Json::CharReader* reader(rbuilder.newCharReader());
-
-	std::string errors;
-	bool success = reader->parse( value.c_str(),
-                 value.c_str() + value.size(), &root, &errors );
-	delete reader;
-
-	if (!success)
-		// Raise exception
-		throw InvalidJSON("JSON could not be parsed (or is invalid)");
-
 	try
 	{
+		const Json::Value root = openshot::stringToJson(value);
 		// Set all values that match
 		SetJsonValue(root);
 	}
@@ -191,8 +179,8 @@ void Profile::SetJson(std::string value) {
 	}
 }
 
-// Load Json::JsonValue into this object
-void Profile::SetJsonValue(Json::Value root) {
+// Load Json::Value into this object
+void Profile::SetJsonValue(const Json::Value root) {
 
 	if (!root["height"].isNull())
 		info.height = root["height"].asInt();
